Reader

Struct Reader 

pub struct Reader<'a> { /* private fields */ }

Implementations

Source

impl Reader<'_>

pub fn get_data(&self) -> &[u8]

Gets the underlying data of the reader.

pub fn get_offset(&self) -> usize

Gets the offset of the reader.

pub fn get_length(&self) -> u64

Gets the length of the reader.

pub fn new(buf: &[u8]) -> Reader<'_>

Creates a new Reader from the provided buffer.

pub fn slice(&self, offset: usize, length: usize) -> Reader<'_>

Slices the Reader’s buffer and returns a new Reader for the slice.

pub fn seek(&mut self, offset: usize, position: u8)

Seek to a new offset, from 0 (start), 1 (current), or 2 (end) of the buffer.

pub fn remaining(&mut self) -> u64

Gets the remaining length of the buffer.

pub fn read_char(&mut self, endianness: bool) -> char

Reads the next char from the buffer.

pub fn read_uint8(&mut self, endianness: bool) -> u8

Reads the next 8 bit unsigned int from the buffer.

pub fn read_uint16(&mut self, endianness: bool) -> u16

Reads the next 16 bit unsigned int from the buffer.

pub fn read_uint32(&mut self, endianness: bool) -> u32

Reads the next 32 bit unsigned int from the buffer.

pub fn read_uint64(&mut self, endianness: bool) -> u64

Reads the next 64 bit unsigned int from the buffer.

pub fn read_int8(&mut self, endianness: bool) -> i8

Reads the next 8 bit signed int from the buffer.

pub fn read_int16(&mut self, endianness: bool) -> i16

Reads the next 16 bit signed int from the buffer.

pub fn read_int32(&mut self, endianness: bool) -> i32

Reads the next 32 bit signed int from the buffer.

pub fn read_int64(&mut self, endianness: bool) -> i64

Reads the next 64 bit signed int from the buffer.

pub fn read_float32(&mut self, endianness: bool) -> f32

Reads the next 32 bit float from the buffer.

pub fn read_float64(&mut self, endianness: bool) -> f64

Reads the next 64 bit float from the buffer.

pub fn read_string(&mut self, length: Option<u32>) -> String

Reads the next string from the buffer, using the provided length or reading till next 00 byte.