pub struct Reader<'a> { /* private fields */ }Implementations
Sourceimpl Reader<'_>
impl Reader<'_>
Sourcepub fn get_offset(&self) -> usize
pub fn get_offset(&self) -> usize
Gets the offset of the reader.
Sourcepub fn get_length(&self) -> u64
pub fn get_length(&self) -> u64
Gets the length of the reader.
Sourcepub fn slice(&self, offset: usize, length: usize) -> Reader<'_>
pub fn slice(&self, offset: usize, length: usize) -> Reader<'_>
Slices the Reader’s buffer and returns a new Reader for the slice.
Sourcepub fn seek(&mut self, offset: usize, position: u8)
pub fn seek(&mut self, offset: usize, position: u8)
Seek to a new offset, from 0 (start), 1 (current), or 2 (end) of the buffer.
Sourcepub fn read_uint8(&mut self, endianness: bool) -> u8
pub fn read_uint8(&mut self, endianness: bool) -> u8
Reads the next 8 bit unsigned int from the buffer.
Sourcepub fn read_uint16(&mut self, endianness: bool) -> u16
pub fn read_uint16(&mut self, endianness: bool) -> u16
Reads the next 16 bit unsigned int from the buffer.
Sourcepub fn read_uint32(&mut self, endianness: bool) -> u32
pub fn read_uint32(&mut self, endianness: bool) -> u32
Reads the next 32 bit unsigned int from the buffer.
Sourcepub fn read_uint64(&mut self, endianness: bool) -> u64
pub fn read_uint64(&mut self, endianness: bool) -> u64
Reads the next 64 bit unsigned int from the buffer.
Sourcepub fn read_int8(&mut self, endianness: bool) -> i8
pub fn read_int8(&mut self, endianness: bool) -> i8
Reads the next 8 bit signed int from the buffer.
Sourcepub fn read_int16(&mut self, endianness: bool) -> i16
pub fn read_int16(&mut self, endianness: bool) -> i16
Reads the next 16 bit signed int from the buffer.
Sourcepub fn read_int32(&mut self, endianness: bool) -> i32
pub fn read_int32(&mut self, endianness: bool) -> i32
Reads the next 32 bit signed int from the buffer.
Sourcepub fn read_int64(&mut self, endianness: bool) -> i64
pub fn read_int64(&mut self, endianness: bool) -> i64
Reads the next 64 bit signed int from the buffer.
Sourcepub fn read_float32(&mut self, endianness: bool) -> f32
pub fn read_float32(&mut self, endianness: bool) -> f32
Reads the next 32 bit float from the buffer.
Sourcepub fn read_float64(&mut self, endianness: bool) -> f64
pub fn read_float64(&mut self, endianness: bool) -> f64
Reads the next 64 bit float from the buffer.
Sourcepub fn read_string(&mut self, length: Option<u32>) -> String
pub fn read_string(&mut self, length: Option<u32>) -> String
Reads the next string from the buffer, using the provided length or reading till next 00 byte.